@@ -10,11 +10,9 @@
 #ifndef __LIBXMLPP_OUTPUTBUFFER_H
 #define __LIBXMLPP_OUTPUTBUFFER_H
 
-#include <string>
+#include <glibmm/ustring.h>
 #include <libxml++/noncopyable.h>
 
-#include <libxml++/api_export.h>
-
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 extern "C"
 {
@@ -32,7 +30,7 @@ namespace xmlpp
    * A child class has to override do_write, and eventually
    * do_close if some actions are required before buffer closing.
    */
-  class LIBXMLPP_API OutputBuffer: public NonCopyable
+  class OutputBuffer: public NonCopyable
   {
     public:
       /**
@@ -42,7 +40,7 @@ namespace xmlpp
        * @warning The encoding is done by libxml. As a consequence, libxml must
        * have a translator to the target encoding.
        */
-      OutputBuffer(const std::string& encoding = std::string());
+      OutputBuffer(const Glib::ustring& encoding = Glib::ustring());
       virtual ~OutputBuffer();
 
     public:
